Regulariser
===========

.. automodule:: stonesoup.regulariser
    :no-members:

.. automodule:: stonesoup.regulariser.base
    :show-inheritance:

Particle
--------

.. automodule:: stonesoup.regulariser.particle
    :show-inheritance:
